@@ -33,7 +33,7 @@ use Exporter 'import';
 our @EXPORT = qw(system_identity suite_run calc_scalability);
 my $datadir = dist_dir("Benchmark-DKbench");
 
-our $VERSION = '2.0_001';
+our $VERSION = '2.0_002';
 
 =head1 NAME
 
@@ -57,43 +57,29 @@ Benchmark::DKbench - Perl Benchmark
 =head1 DESCRIPTION
 
 A Perl benchmark suite for general compute, created to evaluate the comparative
-performance of systems when running the types of Perl workloads that typically
-cause CPU bottlenecks. Can run single or multi-threaded.
+performance of systems when running computationally intensive Perl (both pure Perl
+and XS) workloads. Runs single and multi-threaded and can be fully customized to
+the benchmarks that better suit your own scenario.
 
 The only non-CPAN libraries required to install/run the suite are libdb, libjpeg
-(with headers). Of the CPAN libraries used, BioPerl is optional (requires libxml).
+(with headers). There are a few prerequisite CPAN libraries to load suite, plus
+the optional BioPerl (requires libxml on system) which enables extra benchmarks.
 
 =head1 SCRIPTS
 
 You should only ever need the main script C<dkbench> for the benchmark suite, and,
-perhaps C<setup_dkbench> can help with setup or normalizing your benchmarking
-environment.
+perhaps C<setup_dkbench> can help with setup or standardizing/normalizing your
+benchmarking environment.
 
 =head2 C<dkbench>
 
-The main script that runs the DKbench benchmark suite. The default run (no options)
-will run all the benchmarks both single-threaded and multi-threaded (using all
-detected CPU cores/hyperthreads) and show you scores and multi vs single threaded
-scalability.
+The main script that runs the DKbench benchmark suite. If L<BioPerl> is installed,
+you may want to start your first run with C<dkbench --setup>. Otherwise, there are
+many options to control number of threads, iterations, which benchmarks to run etc:
 
-The scores are such that a reference CPU (Intel Xeon Platinum 8481C - Sapphire Rapids)
-would get 1000 on a single core benchmark run using the default software configuration
-(Linux/Perl 5.36.0/ref CPAN modules).
-
-The multi-thread scalability should approach 100% if each thread runs on a full core
-(i.e. no SMT), and the core can maintain the clock speed it had on the single-thread
-runs. Note that the overall scalability is an average of the benchmarks that drops
-non-scaling outliers (over 2*stdev less than the mean).
-
-The suite will report a Pass/Fail per benchmark. A failure may be caused if you have
-different CPAN module version installed - this is normal, and you will be warned.
-
-The suite uses L<MCE::Loop> to run on the desired number of parallel threads,
-although by default it will run on a single thread.
-
-There are many options to control number of threads, iterations, which benchmarks
-to run etc.
+ dkbench [options]
 
+ Options:
  --threads <i>, -j <i> : Number of benchmark threads (default is 1).
  --multi,       -m     : Multi-threaded using all your CPU cores/threads.
  --iter <i>,    -i <i> : Number of suite iterations (with min/max/avg at the end).
@@ -110,8 +96,33 @@ to run etc.
  --setup               : Download the Genbank data to enable the BioPerl tests.
  --datapath <path>     : Override the path where the expected benchmark data is found.
 
+The default run (no options) will run all the benchmarks both single-threaded and
+multi-threaded (using all detected CPU cores/hyperthreads) and show you scores and
+multi vs single threaded scalability.
+
+The scores are such that a reference CPU (Intel Xeon Platinum 8481C - Sapphire Rapids)
+would get 1000 on a single core benchmark run using the default software configuration
+(Linux/Perl 5.36.0/ref CPAN modules).
+
+The multi-thread scalability should approach 100% if each thread runs on a full core
+(i.e. no SMT), and the core can maintain the clock speed it had on the single-thread
+runs. Note that the overall scalability is an average of the benchmarks that drops
+non-scaling outliers (over 2*stdev less than the mean).
+
+The suite will report a Pass/Fail per benchmark. A failure may be caused if you have
+different CPAN module version installed - this is normal, and you will be warned.
+
+The suite uses L<MCE::Loop> to run on the desired number of parallel threads, although
+there is an option to disable it, which forces a single-thread run.
+
 =head2 C<setup_dkbench>
 
+Simple installer to check/get the reference versions of CPAN modules and download
+the Genbank data file required for the BioPerl benchmarks of the DKbench suite.
+
+It assumes that you have some software already installed (e.g. C<cpanm>), try
+C<setup_dkbench --help> for more details on that.
+
  setup_dkbench [--force --sudo --test --data=s --help]
 
  Options:
@@ -121,16 +132,11 @@ to run etc.
  --data=s : Data dir path to copy files from. Should not need if you installed DKbench.
  --help   : Print this help text and exit.
 
-Simple installer to check/get the reference versions of CPAN modules and download
-the Genbank data file required for the BioPerl benchmarks of the DKbench suite.
+Running it without any options will fetch the data for the BioPerl tests (similar to
+C<dkbench --setup>) and use C<cpanm> to install any missing libraries.
 
-It assumes that you have some software already installed (e.g. C<cpanm>), try
-C<setup_dkbench --help> for more details.
-
-Running it without any options is the same as C<dkbench --setup>: it will simply
-fetch the data for the BioPerl tests. Using it with C<--force> will install the
-reference CPAN module versions, including BioPerl which is not a requirement for
-DKbench, but enables the BioPerl benchmarks.
+Using it with C<--force> will install the reference CPAN module versions, including
+BioPerl which is not a requirement for DKbench, but enables the BioPerl benchmarks.
 
 The reference CPAN versions are suggested if you want a fair comparison between
 systems and also for the benchmark Pass/Fail results to be reliable.
